@@ -13,13 +13,13 @@
 using namespace Struct;
 
 /******** Produit vecteur--vecteur *********/
-void MultCVDouble (const CVDouble & A, const CVDouble & B, CVDouble & Res) throw (Exception);
+void MultCVDouble (const CVDouble & A, const CVDouble & B, CVDouble & Res); // throw (Exception);
 
 /********* Produit Matric--vecteur *********/
-void MultCVDouble (const CMatDouble & A, const CVDouble & B, CVDouble & Res) throw (Exception)
+void MultCVDouble (const CMatDouble & A, const CVDouble & B, CVDouble & Res); // throw (Exception)
 ;
 
 /*************** Produit Matrice--Matrice  ***************/
-void MultCVDouble (const CMatDouble & A, const CMatDouble & B, CMatDouble & Res) throw (Exception);
+void MultCVDouble (const CMatDouble & A, const CMatDouble & B, CMatDouble & Res); // throw (Exception);
 
 #endif // OPERATEURS_H
